//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
#include "VKPhysicsListMessenger.hh"

#include "G4UIcmdWithADoubleAndUnit.hh"
#include "G4UIcmdWith3VectorAndUnit.hh"
#include "G4UIcmdWithAnInteger.hh"
#include "G4UIcommand.hh"
#include "G4UIdirectory.hh"
#include "G4UIcmdWithABool.hh"
#include "G4UIcmdWithADouble.hh"
#include "G4Scintillation.hh"


VKPhysicsListMessenger::VKPhysicsListMessenger(VKPhysicsList* pPhysicsList)
 : fPhysicsList(pPhysicsList)
{
    // Setup a command directory for detector controls with guidance
    fPhysicsListDir = new G4UIdirectory("/VK/physics/");
    fPhysicsListDir->SetGuidance("Physics list control");
       
    // Various commands for modifying physics list
    fOpticalPhysicsCmd = new G4UIcmdWithABool("/VK/physics/opticalPhysics", this);
    fOpticalPhysicsCmd->SetGuidance("Enable/disable optical physics.");
    fOpticalPhysicsCmd->AvailableForStates(G4State_PreInit);
    fOpticalPhysicsCmd->SetToBeBroadcasted(false);
}


VKPhysicsListMessenger::~VKPhysicsListMessenger()
{
    delete fOpticalPhysicsCmd;
}


void VKPhysicsListMessenger::SetNewValue(G4UIcommand* command, G4String newValue)
{
    if (command == fOpticalPhysicsCmd)
    {
        fPhysicsList -> SetOpticalPhysicsOn(fOpticalPhysicsCmd -> GetNewBoolValue(newValue));
    }
}
